@@ -4,16 +4,16 @@ Sungai.
 - Project URL: https://github.com/hugocartwright/sungai
 """
 import argparse
-import os
 import sys
+from pathlib import Path
 
 from .sungai import DirectoryRater
 
-__version__ = "0.1.0"
+__version__ = "0.1.6"
 
 
-def run_sungai():
-    """Run sungai."""
+def get_args():  # pragma: no cover
+    """Get command line arguments."""
     parser = argparse.ArgumentParser(
         description="Sungai"
     )
@@ -29,6 +29,13 @@ def run_sungai():
         required=False,
         default=None,
     )
+    parser.add_argument(
+        "--ignore_config",
+        type=str,
+        help="The ignore config file path. Must follow .gitignore syntax.",
+        required=False,
+        default=None,
+    )
     parser.add_argument(
         "--verbose",
         action="store_true",
@@ -36,18 +43,39 @@ def run_sungai():
         required=False,
         default=False,
     )
-    args = parser.parse_args()
+
+    return parser.parse_args()
+
+
+def run_sungai():  # pragma: no cover
+    """Run sungai."""
+    args = get_args()
+
+    target = Path(args.target)
+
+    if not target.is_dir():
+        print("[sungai] Error: Target not found")
+        sys.exit(1)
+
+    ignore_config = None
+    if args.ignore_config:
+        ignore_config = Path(args.ignore_config)
+        if not ignore_config.is_file():
+            print("[sungai] Error: Could not find ignore_config file")
+            sys.exit(1)
 
     try:
         print(f"Sungai ({__version__})")
-        target = os.path.normpath(args.target)
-        if os.path.isdir(target):
-            directory_rater = DirectoryRater(
-                target,
+
+        directory_rater = DirectoryRater(
+            target,
+            ignore_config=ignore_config,
+        )
+        sys.exit(
+            directory_rater.run(
+                verbose=args.verbose,
+                min_score=args.min_score,
             )
-            sys.exit(directory_rater.run(args.verbose, args.min_score))
-        else:
-            print("[sungai] Error: Target not found")
-            sys.exit(1)
+        )
     except KeyboardInterrupt:
         sys.exit(1)
